@@ -4,7 +4,6 @@ from __future__ import print_function
 from __future__ import unicode_literals
 
 import socket
-import ftplib
 import os
 import platform
 import shutil
@@ -13,8 +12,7 @@ import time
 import unittest
 import uuid
 
-from nose.plugins.attrib import attr
-
+import pytest
 from six import text_type
 
 from ftplib import error_perm
@@ -114,8 +112,24 @@ class TestFTPErrors(unittest.TestCase):
             with ftp_errors(mem_fs):
                 raise error_perm("999 foo")
 
+    def test_manager_with_host(self):
+        mem_fs = open_fs("mem://")
+        mem_fs.host = "ftp.example.com"
 
-@attr("slow")
+        with self.assertRaises(errors.RemoteConnectionError) as err_info:
+            with ftp_errors(mem_fs):
+                raise EOFError
+        self.assertEqual(str(err_info.exception), "lost connection to ftp.example.com")
+
+        with self.assertRaises(errors.RemoteConnectionError) as err_info:
+            with ftp_errors(mem_fs):
+                raise socket.error
+        self.assertEqual(
+            str(err_info.exception), "unable to connect to ftp.example.com"
+        )
+
+
+@pytest.mark.slow
 class TestFTPFS(FSTestCases, unittest.TestCase):
 
     user = "user"
@@ -166,26 +180,39 @@ class TestFTPFS(FSTestCases, unittest.TestCase):
         super(TestFTPFS, self).tearDown()
 
     def test_ftp_url(self):
-        self.assertEqual(self.fs.ftp_url, "ftp://{}:{}@{}:{}".format(self.user, self.pasw, self.server.host, self.server.port))
-        
+        self.assertEqual(
+            self.fs.ftp_url,
+            "ftp://{}:{}@{}:{}".format(
+                self.user, self.pasw, self.server.host, self.server.port
+            ),
+        )
+
     def test_geturl(self):
         self.fs.makedir("foo")
         self.fs.create("bar")
         self.fs.create("foo/bar")
         self.assertEqual(
-            self.fs.geturl('foo'), "ftp://{}:{}@{}:{}/foo".format(self.user, self.pasw, self.server.host, self.server.port)
+            self.fs.geturl("foo"),
+            "ftp://{}:{}@{}:{}/foo".format(
+                self.user, self.pasw, self.server.host, self.server.port
+            ),
         )
         self.assertEqual(
-            self.fs.geturl('bar'), "ftp://{}:{}@{}:{}/bar".format(self.user, self.pasw, self.server.host, self.server.port)
+            self.fs.geturl("bar"),
+            "ftp://{}:{}@{}:{}/bar".format(
+                self.user, self.pasw, self.server.host, self.server.port
+            ),
         )
         self.assertEqual(
-            self.fs.geturl('foo/bar'), "ftp://{}:{}@{}:{}/foo/bar".format(self.user, self.pasw, self.server.host, self.server.port)
+            self.fs.geturl("foo/bar"),
+            "ftp://{}:{}@{}:{}/foo/bar".format(
+                self.user, self.pasw, self.server.host, self.server.port
+            ),
         )
 
     def test_host(self):
         self.assertEqual(self.fs.host, self.server.host)
 
-    # @attr('slow')
     def test_connection_error(self):
         fs = FTPFS("ftp.not.a.chance", timeout=1)
         with self.assertRaises(errors.RemoteConnectionError):
@@ -251,8 +278,8 @@ class TestFTPFSNoMLSD(TestFTPFS):
     def test_features(self):
         pass
 
-    
-@attr("slow")
+
+@pytest.mark.slow
 class TestAnonFTPFS(FSTestCases, unittest.TestCase):
 
     user = "anonymous"
@@ -288,11 +315,7 @@ class TestAnonFTPFS(FSTestCases, unittest.TestCase):
         super(TestAnonFTPFS, cls).tearDownClass()
 
     def make_fs(self):
-        return open_fs(
-            "ftp://{}:{}".format(
-                self.server.host, self.server.port
-            )
-        )
+        return open_fs("ftp://{}:{}".format(self.server.host, self.server.port))
 
     def tearDown(self):
         shutil.rmtree(self._temp_path)
@@ -300,12 +323,23 @@ class TestAnonFTPFS(FSTestCases, unittest.TestCase):
         super(TestAnonFTPFS, self).tearDown()
 
     def test_ftp_url(self):
-        self.assertEqual(self.fs.ftp_url, "ftp://{}:{}".format(self.server.host, self.server.port))
+        self.assertEqual(
+            self.fs.ftp_url, "ftp://{}:{}".format(self.server.host, self.server.port)
+        )
 
     def test_geturl(self):
         self.fs.makedir("foo")
         self.fs.create("bar")
         self.fs.create("foo/bar")
-        self.assertEqual(self.fs.geturl('foo'), "ftp://{}:{}/foo".format(self.server.host, self.server.port))
-        self.assertEqual(self.fs.geturl('bar'), "ftp://{}:{}/bar".format(self.server.host, self.server.port))
-        self.assertEqual(self.fs.geturl('foo/bar'), "ftp://{}:{}/foo/bar".format(self.server.host, self.server.port))
+        self.assertEqual(
+            self.fs.geturl("foo"),
+            "ftp://{}:{}/foo".format(self.server.host, self.server.port),
+        )
+        self.assertEqual(
+            self.fs.geturl("bar"),
+            "ftp://{}:{}/bar".format(self.server.host, self.server.port),
+        )
+        self.assertEqual(
+            self.fs.geturl("foo/bar"),
+            "ftp://{}:{}/foo/bar".format(self.server.host, self.server.port),
+        )
