@@ -4,20 +4,23 @@ from __future__ import unicode_literals
 import errno
 import io
 import os
-import mock
 import shutil
 import tempfile
 import unittest
+import pytest
 
-from fs import osfs
-from fs import fsencode, fsdecode
-from fs.path import relpath
+from fs import osfs, open_fs
+from fs.path import relpath, dirname
 from fs import errors
-
 from fs.test import FSTestCases
 
 from six import text_type
 
+try:
+    from unittest import mock
+except ImportError:
+    import mock
+
 
 class TestOSFS(FSTestCases, unittest.TestCase):
     """Test OSFS implementation."""
@@ -28,6 +31,11 @@ class TestOSFS(FSTestCases, unittest.TestCase):
 
     def destroy_fs(self, fs):
         self.fs.close()
+        try:
+            shutil.rmtree(fs.getsyspath("/"))
+        except OSError:
+            # Already deleted
+            pass
 
     def _get_real_path(self, path):
         _path = os.path.join(self.fs.root_path, relpath(path))
@@ -67,7 +75,7 @@ class TestOSFS(FSTestCases, unittest.TestCase):
 
     def test_not_exists(self):
         with self.assertRaises(errors.CreateFailed):
-            fs = osfs.OSFS("/does/not/exists/")
+            osfs.OSFS("/does/not/exists/")
 
     def test_expand_vars(self):
         self.fs.makedir("TYRIONLANISTER")
@@ -79,11 +87,11 @@ class TestOSFS(FSTestCases, unittest.TestCase):
         self.assertIn("TYRIONLANISTER", fs1.getsyspath("/"))
         self.assertNotIn("TYRIONLANISTER", fs2.getsyspath("/"))
 
-    @unittest.skipIf(osfs.sendfile is None, "sendfile not supported")
+    @pytest.mark.skipif(osfs.sendfile is None, reason="sendfile not supported")
     def test_copy_sendfile(self):
         # try copying using sendfile
         with mock.patch.object(osfs, "sendfile") as sendfile:
-            sendfile.side_effect = OSError(errno.ENOTSUP, "sendfile not supported")
+            sendfile.side_effect = OSError(errno.ENOSYS, "sendfile not supported")
             self.test_copy()
         # check other errors are transmitted
         self.fs.touch("foo")
@@ -125,7 +133,7 @@ class TestOSFS(FSTestCases, unittest.TestCase):
         finally:
             shutil.rmtree(dir_path)
 
-    @unittest.skipIf(not hasattr(os, "symlink"), "No symlink support")
+    @pytest.mark.skipif(not hasattr(os, "symlink"), reason="No symlink support")
     def test_symlinks(self):
         with open(self._get_real_path("foo"), "wb") as f:
             f.write(b"foobar")
@@ -152,3 +160,40 @@ class TestOSFS(FSTestCases, unittest.TestCase):
             with self.assertRaises(errors.InvalidCharsInPath):
                 with self.fs.open("13 – Marked Register.pdf", "wb") as fh:
                     fh.write(b"foo")
+
+    def test_consume_geturl(self):
+        self.fs.create("foo")
+        try:
+            url = self.fs.geturl("foo", purpose="fs")
+        except errors.NoURL:
+            self.assertFalse(self.fs.hasurl("foo"))
+        else:
+            self.assertTrue(self.fs.hasurl("foo"))
+
+        # Should not throw an error
+        base_dir = dirname(url)
+        open_fs(base_dir)
+
+    def test_complex_geturl(self):
+        self.fs.makedirs("foo/bar ha")
+        test_fixtures = [
+            # test file, expected url path
+            ["foo", "foo"],
+            ["foo-bar", "foo-bar"],
+            ["foo_bar", "foo_bar"],
+            ["foo/bar ha/barz", "foo/bar%20ha/barz"],
+            ["example b.txt", "example%20b.txt"],
+            ["exampleㄓ.txt", "example%E3%84%93.txt"],
+        ]
+        file_uri_prefix = "osfs://"
+        for test_file, relative_url_path in test_fixtures:
+            self.fs.create(test_file)
+            expected = file_uri_prefix + self.fs.getsyspath(relative_url_path).replace(
+                "\\", "/"
+            )
+            actual = self.fs.geturl(test_file, purpose="fs")
+
+            self.assertEqual(actual, expected)
+
+    def test_geturl_return_no_url(self):
+        self.assertRaises(errors.NoURL, self.fs.geturl, "test/path", "upload")
