@@ -4,10 +4,14 @@ import os
 
 from fs.tempfs import TempFS
 from fs import errors
-import mock
 
 from .test_osfs import TestOSFS
 
+try:
+    from unittest import mock
+except ImportError:
+    import mock
+
 
 class TestTempFS(TestOSFS):
     """Test OSFS implementation."""
